==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_article_modify.php <==
<?php
class ArticleModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function art_params($artId) {
		$query = "SELECT ID,USERID,HIDE,PAGEID FROM ".ARTICLES." WHERE ID = ".$artId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function update_article($artId) {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		/* in case of no page created		*/
		$siteDat = $this->home_params();
		$content = $this->h->safe($_POST['content']);
		$pageId = isset($_POST['pageid'])?$this->h->num($_POST['pageid']):$siteDat['SANDBOXID'];
		$query = "UPDATE ".ARTICLES."  SET SUBJECT = '".$this->h->safe($_POST['subject'])."'".
										",USERID = ".$this->h->num($_POST['userid']);
		$query .= isset($_POST['updateDate'])?",DATE = '".$date."'":"";
		$query .=						",CONTENT = '".$content."'".
										",HIDE = ".$hide.
										",PAGEID = ".$pageId.
										" WHERE ID = ".$artId;
		$query = $this->q($query);
		$result = $this->h->h3("article ".strip_tags($_POST['subject'])." updated !");
		return $result;
	}
	public function data_article($artId) {
		$siteDat = $this->home_params();
		$queryLevel1 = "SELECT * FROM ".ARTICLES." WHERE ID = ".$artId.";";
		$queryLevel2 = $queryLevel1;
		$queryLevel3 = "SELECT * FROM ".ARTICLES." WHERE ID = ".$artId." AND USERID = ".$_SESSION['userid'].";";
		$queryLevel4 = "SELECT * FROM ".ARTICLES." WHERE ID = ".$artId." AND PAGEID = ".$siteDat['SANDBOXID'].";";
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3,$queryLevel4);
		$query = $queries[$_SESSION['level']];
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat) {
			$content = $this->h->input("hidden","update",1);
			$content .= $this->h->input("hidden","art",$dat['ID']);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->h->p("(id:".$dat['ID'].")".$this->tr->wsb("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= ($_SESSION['level'] < 4)?$this->h->p($this->tr->ws("choose page").$this->SelectUserPages("pageid",$dat['PAGEID'])):$this->h->p("page: SandBox").$this->h->input("hidden","pageid",$siteDat['SANDBOXID']);
			$content .= $this->h->p($this->tr->w("subject (not displayed only info)")).$this->h->p($this->h->input("content","subject",htmlentities($dat['SUBJECT']),"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->ws("content")).$this->h->p($this->h->textarea($dat['CONTENT'],"content",array(12,FIELDWIDTH)));
			$content .= $this->h->p($this->tr->ws("update date")."(".$dat['DATE'].")".$this->h->input("checkbox","updateDate","1"));
			$content .= $this->h->input("hidden","userid",$_SESSION['userid']);
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"article","post","admin.php?action=modify_article");
			return $result;
		}
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_article_modify.php <==
<?php
class ArticleModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
        $this->tree = New Tree();
	}
	public function art_params($artId) {
		$query = "SELECT ID,USERID,HIDE,PAGEID FROM ".ARTICLES." WHERE ID = ".$artId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function update_article($artId) {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		/* in case of no page created		*/
		$siteDat = $this->home_params();
		$content = $this->h->safe($_POST['content']);
		$pageId = isset($_POST['parent'])?$this->h->num($_POST['parent']):$siteDat['SANDBOXID'];
		$query = "UPDATE ".ARTICLES."  SET SUBJECT = '".$this->h->safe($_POST['subject'])."'".
										",USERID = ".$this->h->num($_POST['userid']);
		$query .= isset($_POST['updateDate'])?",DATE = '".$date."'":"";
		$query .=						",CONTENT = '".$content."'".
										",HIDE = ".$hide.
										",PAGEID = ".$pageId.
										" WHERE ID = ".$artId;
		$query = $this->q($query);
		$result = $this->h->h3("article ".strip_tags($_POST['subject'])." updated !");
		return $result;
	}
	public function data_article($artId) {
		$siteDat = $this->home_params();
		$queryLevel1 = "SELECT * FROM ".ARTICLES." WHERE ID = ".$artId.";";
		$queryLevel2 = $queryLevel1;
		$queryLevel3 = "SELECT * FROM ".ARTICLES." WHERE ID = ".$artId." AND USERID = ".$_SESSION['userid'].";";
		$queryLevel4 = "SELECT * FROM ".ARTICLES." WHERE ID = ".$artId." AND PAGEID = ".$siteDat['SANDBOXID'].";";
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3,$queryLevel4);
		$query = $queries[$_SESSION['level']];
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		if ($dat) {
			$content = $this->h->input("hidden","update",1);
			$content .= $this->h->input("hidden","art",$dat['ID']);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->h->p("(id:".$dat['ID'].")".$this->tr->wsb("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= ($_SESSION['level'] < 4)?$this->h->p($this->tr->ws("choose page").$this->tree->pathsSelect($dat['PAGEID'])):$this->h->p("page: SandBox").$this->h->input("hidden","pageid",$siteDat['SANDBOXID']);
			$content .= $this->h->p($this->tr->w("subject (not displayed only info)")).$this->h->p($this->h->input("content","subject",htmlentities($dat['SUBJECT']),"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->ws("content")).$this->h->p($this->h->textarea($dat['CONTENT'],"content",array(12,FIELDWIDTH)));
			$content .= $this->h->p($this->tr->ws("update date")."(".$dat['DATE'].")".$this->h->input("checkbox","updateDate","1"));
			$content .= $this->h->input("hidden","userid",$_SESSION['userid']);
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"article","post","admin.php?action=modify_article");
			return $result;
		}
	}
}
?>
